import { Client } from './client';
import { ChannelEvent, Distribute, Task } from './task';
export interface Channel {
    channel: ChannelType | null;
    state: string;
    joined_at: number;
    timeout?: number;
    active: boolean;
    open: number;
    wrap_time_ids: number[];
}
export interface AgentSession {
    agent_id: number;
    status: string;
    on_demand: boolean;
    last_status_change: number;
    status_duration: number;
    status_payload: any;
    channels: Channel[];
    is_supervisor: boolean;
    is_admin: boolean;
    team: object | null;
    supervisor: object | null;
    auditor: object | null;
}
export interface AgentSessionResponse extends AgentSession {
    task?: Distribute[];
}
export interface AgentStatusEvent {
    user_id: number;
    agent_id: number;
    timestamp: number;
    status: string;
    status_payload?: any;
    timeout?: number;
    channels: Channel[];
    on_demand?: boolean;
}
export declare enum AgentStatus {
    Online = "online",
    Offline = "offline",
    Pause = "pause",
    BreakOut = "break_out"
}
export declare enum ChannelState {
    Waiting = "waiting",
    Distribute = "distribute",
    Offering = "offering",
    Answered = "answered",
    Active = "active",
    Bridged = "bridged",
    Hold = "hold",
    Missed = "missed",
    WrapTime = "wrap_time",
    Processing = "processing",
    Transfer = "transfer"
}
export declare enum ChannelType {
    Call = "call",
    Email = "email",
    Chat = "chat"
}
export declare class Agent {
    protected readonly client: Client;
    protected info: AgentSession;
    task: Map<number, Task>;
    _channel: Channel;
    lastStatusChange: number;
    constructor(client: Client, info: AgentSession);
    get agentId(): number;
    get onDemand(): boolean;
    get status(): string;
    get statusPayload(): any;
    get isAdmin(): boolean;
    get isSupervisor(): boolean;
    get team(): object | null;
    get supervisor(): object | null;
    get auditor(): object | null;
    get channels(): Channel[];
    get channel(): Channel;
    get stateDuration(): number;
    onChannelEvent(e: ChannelEvent): Task | undefined;
    online(channels: string[], onDemand: boolean): Promise<object>;
    waiting(channel: string): Promise<object>;
    pause(payload?: any): Promise<object>;
    offline(): Promise<object>;
    setStatus(e: AgentStatusEvent): void;
    directMember(memberId: number, communicationId: number): Promise<object>;
    offlineMembers(q: string, page: number, perPage: number): Promise<object>;
    hasTask(task: Task): boolean;
    private setChannelState;
    private setChannelStateTimeout;
}
//# sourceMappingURL=agent.d.ts.map