import { CallVariables, Categories } from './call';
import { Client } from './client';
export interface Reporting {
    success?: boolean;
    agent_id?: number;
    next_distribute_at?: number;
    categories?: Categories;
    communication?: MemberCommunication;
    new_communication?: MemberCommunication[];
    description?: string;
    display?: boolean;
    expire?: number;
    variables?: CallVariables;
    name?: string;
    timezone?: object;
}
export declare enum ChannelName {
    Call = "call",
    Chat = "chat",
    Task = "task"
}
export interface Node {
    id: number;
    name: string;
    value: object;
    children?: Node[];
}
export interface CommunicationType {
    id: number;
    name: string;
}
export interface MemberCommunication {
    destination: string;
    type: CommunicationType;
    display?: string;
    state?: number;
}
export interface ChannelEvent {
    status: string;
    attempt_id?: number;
    timestamp: number;
    channel: string;
}
export interface Distribute extends ChannelEvent {
    app_id: string;
    queue_id: number;
    queue_name: string;
    member_id: number;
    agent_id?: number;
    member_channel_id?: string;
    agent_channel_id?: string;
    communication: MemberCommunication;
    has_reporting: boolean;
}
export interface TaskData extends Distribute {
    bridged_at?: number;
    leaving_at?: number;
    processing_sec?: number;
    processing_renewal_sec?: number;
    duration: number;
    state: string;
}
export interface Offering {
    member_channel_id?: string;
    agent_channel_id?: string;
}
export interface Missed {
    timeout: number;
    no_answers: number;
}
export interface WrapTime {
    timeout: number;
}
export interface Processing {
    timeout: number;
    sec: number;
    renewal_sec?: number;
}
export interface DistributeEvent extends ChannelEvent {
    distribute: Distribute;
}
export interface TransferEvent extends ChannelEvent {
    to_attempt_id: number;
    distribute: Distribute;
}
export interface MissedEvent extends ChannelEvent {
    missed: Missed;
}
export interface WrapTimeEvent extends ChannelEvent {
    wrap_time: WrapTime;
}
export interface ProcessingEvent extends ChannelEvent {
    processing: Processing;
}
export interface Queue {
    id: number;
    name: string;
}
export declare class Task {
    private readonly client;
    protected distribute: Distribute;
    history: Distribute[];
    communication: MemberCommunication;
    id: number;
    state: string;
    postProcessData: object;
    lastStatusChange: number;
    createdAt: number;
    offeringAt: number;
    answeredAt: number;
    bridgedAt: number;
    startProcessingAt: number;
    stopAt: number;
    closedAt: number;
    reportedAt: number;
    _processing: Processing | null;
    constructor(client: Client, e: ChannelEvent, distribute: Distribute);
    get queue(): Queue;
    get duration(): number;
    get channel(): string;
    get allowAccept(): boolean;
    get allowDecline(): boolean;
    get allowClose(): boolean;
    get memberId(): number;
    get queueId(): number;
    get hasReporting(): boolean;
    get allowReporting(): boolean;
    get agentChannelId(): string | undefined;
    setAnswered(t: number): void;
    setBridged(t: number): void;
    setProcessing(p: Processing): void;
    setTransferred(d: Distribute): void;
    get processingTimeoutAt(): number | null;
    get processingSec(): number | null;
    get renewalSec(): number | null;
    accept(): Promise<object>;
    close(): Promise<object>;
    decline(): Promise<object>;
    reporting(reporting: Reporting): Promise<object>;
    renew(sec?: number): Promise<object>;
}
//# sourceMappingURL=task.d.ts.map